Platform dependent audio device streaming implementations.
To make use of this module enable one of the available features to the spectrusty_audio entry in [dependencies]
section of the Cargo configuration file.
Modules
- cpal
- Audio device streaming implementation for cpal.
- sdl2
- Audio device streaming implementation for SDL2.
Structs
- Audio
Handle Error - A common error type returned by all audio handle implementation methods in this module.
Enums
- Audio
Handle Error Kind - A list specifying categories of AudioHandleError error.